This is the mail archive of the binutils@sources.redhat.com mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] gas: Fix comment typos.


Hi,

Attached is a patch to fix comment typos.  Committed as obvious.

Kazu Hirata

2003-10-27  Kazu Hirata  <kazu@cs.umass.edu>

	* ChangeLog: Fix typos.
	* ChangeLog-9295: Likewise.
	* as.c: Fix comment typos.
	* as.h: Likewise.
	* atof-generic.c: Likewise.
	* bit_fix.h: Likewise.
	* frags.h: Likewise.
	* hash.c: Likewise.
	* input-file.c: Likewise.
	* input-scrub.c: Likewise.
	* itbl-ops.c: Likewise.
	* itbl-parse.y: Likewise.
	* listing.c: Likewise.
	* macro.h: Likewise.
	* read.c: Likewise.
	* sb.c: Likewise.
	* sb.h: Likewise.
	* symbols.c: Likewise.
	* symbols.h: Likewise.

Index: ChangeLog
===================================================================
RCS file: /cvs/src/src/gas/ChangeLog,v
retrieving revision 1.1937
diff -u -r1.1937 ChangeLog
--- ChangeLog	27 Oct 2003 09:57:59 -0000	1.1937
+++ ChangeLog	27 Oct 2003 12:40:33 -0000
@@ -2419,7 +2419,7 @@
 	operands.
 	(OPTION_MIPS32R2): New define.
 	(md_longopts): Add entry for OPTION_MIPS32R2.
-	(OPTION_ELF_BASE): Adjust to accomodate OPTIONS_MIPS32R2.
+	(OPTION_ELF_BASE): Adjust to accommodate OPTIONS_MIPS32R2.
 	(md_parse_option): Handle OPTION_MIPS32R2.
 	(s_mipsset): Reimplement handling of ".set mipsN" options
 	and add support for ".set mips32r2".
@@ -4999,7 +4999,7 @@
 	types.
 	(OPTION_MDMX, OPTION_NO_MDMX, md_longopts, md_parse_option):
 	Add support for "-mdmx" and "-no-mdmx" options.
-	(OPTION_ELF_BASE): Move to accomodate new options.
+	(OPTION_ELF_BASE): Move to accommodate new options.
 	(s_mipsset): Support ".set mdmx" and ".set nomdmx".
 	(mips_elf_final_processing): Set MDMX ASE ELF header flag if
 	file_ase_mdmx was set.
@@ -5638,7 +5638,7 @@
 	mips_opts.ase_mips3d is set.
 	(OPTION_MIPS3D, OPTION_NO_MIPS3D, md_longopts, md_parse_option):
 	Add support for "-mips3d" and "-no-mips3d" options.
-	(OPTION_ELF_BASE): Move to accomodate new options.
+	(OPTION_ELF_BASE): Move to accommodate new options.
 	(s_mipsset): Support ".set mips3d" and ".set nomips3d".
 	(mips_elf_final_processing): Add a comment indicating that a
 	MIPS-3D ASE ELF header flag should be set, when one exists.
Index: ChangeLog-9295
===================================================================
RCS file: /cvs/src/src/gas/ChangeLog-9295,v
retrieving revision 1.3
diff -u -r1.3 ChangeLog-9295
--- ChangeLog-9295	17 Dec 2002 01:13:54 -0000	1.3
+++ ChangeLog-9295	27 Oct 2003 12:40:42 -0000
@@ -9003,7 +9003,7 @@
 	* app.c (do_scrub_next_char): Always accept 'x' and 'X' as escape
 	characters in state 6.
 	* read.c (next_char_of_string): Accept \Xh* and \xh* where h* are
-	hexidecimal digits.
+	hexadecimal digits.
 
 	* config/tc-i386.c (md_apply_fix_1): Make cross segment calls work
 	for ELF by hacking around bizarre bfd_perform_relocation behaviour
@@ -13007,7 +13007,7 @@
 	* app.c: MRI compatibility - allow single quote to start a string.
 	* as.c: fix typo recently introduced.
 	* as.h : Don't include aout/reloc.h - it's not right for COFF!
-	* expr.c: Much rewriting, to accomodate MRI syntax for
+	* expr.c: Much rewriting, to accommodate MRI syntax for
 	expressions. Also easier to read now.
 	* listing.c: Put back defuns
 	* read.c: modified to accept MRI syntax, put back listing pseudo
Index: as.c
===================================================================
RCS file: /cvs/src/src/gas/as.c,v
retrieving revision 1.50
diff -u -r1.50 as.c
--- as.c	8 Oct 2003 14:37:20 -0000	1.50
+++ as.c	27 Oct 2003 12:40:43 -0000
@@ -501,7 +501,7 @@
 	  if (md_parse_option (optc, optarg) != 0)
 	    break;
 	  /* `-v' isn't included in the general short_opts list, so check for
-	     it explicity here before deciding we've gotten a bad argument.  */
+	     it explicitly here before deciding we've gotten a bad argument.  */
 	  if (optc == 'v')
 	    {
 #ifdef VMS
Index: as.h
===================================================================
RCS file: /cvs/src/src/gas/as.h,v
retrieving revision 1.34
diff -u -r1.34 as.h
--- as.h	8 Oct 2003 14:37:20 -0000	1.34
+++ as.h	27 Oct 2003 12:40:43 -0000
@@ -237,7 +237,7 @@
 #ifdef TEST
 #define COMMON			/* declare our COMMONs storage here.  */
 #else
-#define COMMON extern		/* our commons live elswhere */
+#define COMMON extern		/* our commons live elsewhere */
 #endif
 #endif
 /* COMMON now defined */
Index: atof-generic.c
===================================================================
RCS file: /cvs/src/src/gas/atof-generic.c,v
retrieving revision 1.6
diff -u -r1.6 atof-generic.c
--- atof-generic.c	19 Sep 2001 05:33:18 -0000	1.6
+++ atof-generic.c	27 Oct 2003 12:40:44 -0000
@@ -472,7 +472,7 @@
       {
 	/*
 	 * Compute the mantssa (& exponent) of the power of 10.
-	 * If sucessful, then multiply the power of 10 by the digits
+	 * If successful, then multiply the power of 10 by the digits
 	 * giving return_binary_mantissa and return_binary_exponent.
 	 */
 
Index: bit_fix.h
===================================================================
RCS file: /cvs/src/src/gas/bit_fix.h,v
retrieving revision 1.6
diff -u -r1.6 bit_fix.h
--- bit_fix.h	17 Oct 2001 05:51:11 -0000	1.6
+++ bit_fix.h	27 Oct 2003 12:40:44 -0000
@@ -20,7 +20,7 @@
 
 /* The bit_fix was implemented to support machines that need variables
    to be inserted in bitfields other than 1, 2 and 4 bytes.
-   Furthermore it gives us a possibillity to mask in bits in the symbol
+   Furthermore it gives us a possibility to mask in bits in the symbol
    when it's fixed in the objectcode and check the symbols limits.
 
    The or-mask is used to set the huffman bits in displacements for the
Index: frags.h
===================================================================
RCS file: /cvs/src/src/gas/frags.h,v
retrieving revision 1.12
diff -u -r1.12 frags.h
--- frags.h	3 May 2002 02:25:33 -0000	1.12
+++ frags.h	27 Oct 2003 12:40:44 -0000
@@ -116,7 +116,7 @@
 
 #if 0
 /* A macro to speed up appending exactly 1 char to current frag.  */
-/* JF changed < 1 to <= 1 to avoid a race conditon.  */
+/* JF changed < 1 to <= 1 to avoid a race condition.  */
 #define FRAG_APPEND_1_CHAR(datum)			\
 {							\
   if (obstack_room (&frags) <= 1)			\
Index: hash.c
===================================================================
RCS file: /cvs/src/src/gas/hash.c,v
retrieving revision 1.9
diff -u -r1.9 hash.c
--- hash.c	26 Jun 2002 01:18:42 -0000	1.9
+++ hash.c	27 Oct 2003 12:40:44 -0000
@@ -430,7 +430,7 @@
 /* We test many hash tables at once.  */
 char *hashtable[TABLES];
 
-/* Points to curent hash_control.  */
+/* Points to current hash_control.  */
 char *h;
 char **pp;
 char *p;
Index: input-file.c
===================================================================
RCS file: /cvs/src/src/gas/input-file.c,v
retrieving revision 1.10
diff -u -r1.10 input-file.c
--- input-file.c	18 May 2002 12:53:30 -0000	1.10
+++ input-file.c	27 Oct 2003 12:40:44 -0000
@@ -58,7 +58,7 @@
     char * app_save;
   };
 
-/* These hooks accomodate most operating systems.  */
+/* These hooks accommodate most operating systems.  */
 
 void
 input_file_begin ()
Index: input-scrub.c
===================================================================
RCS file: /cvs/src/src/gas/input-scrub.c,v
retrieving revision 1.9
diff -u -r1.9 input-scrub.c
--- input-scrub.c	1 Aug 2001 01:44:25 -0000	1.9
+++ input-scrub.c	27 Oct 2003 12:40:44 -0000
@@ -33,7 +33,7 @@
  * were broken across buffers, and return a buffer of full lines to
  * the caller.
  * The last partial line begins the next buffer we build and return to caller.
- * The buffer returned to caller is preceeded by BEFORE_STRING and followed
+ * The buffer returned to caller is preceded by BEFORE_STRING and followed
  * by AFTER_STRING, as sentinels. The last character before AFTER_STRING
  * is a newline.
  * Also looks after line numbers, for e.g. error messages.
Index: itbl-ops.c
===================================================================
RCS file: /cvs/src/src/gas/itbl-ops.c,v
retrieving revision 1.11
diff -u -r1.11 itbl-ops.c
--- itbl-ops.c	30 Oct 2002 03:56:39 -0000	1.11
+++ itbl-ops.c	27 Oct 2003 12:40:45 -0000
@@ -351,7 +351,7 @@
       printf (_("Unable to allocate memory for new instructions\n"));
       return;
     }
-  if (size)			/* copy prexisting opcodes table */
+  if (size)			/* copy preexisting opcodes table */
     memcpy (new_opcodes, ITBL_OPCODES, size);
 
   /* FIXME! some NUMOPCODES are calculated expressions.
@@ -372,13 +372,13 @@
 	  o->name = e->name;
 	  o->args = strdup (form_args (e));
 	  o->mask = apply_range (e->value, e->range);
-	  /* FIXME how to catch durring assembly? */
+	  /* FIXME how to catch during assembly? */
 	  /* mask to identify this insn */
 	  o->match = apply_range (e->value, e->range);
 	  o->pinfo = 0;
 
 #ifdef USE_MACROS
-	  o->mask = id++;	/* FIXME how to catch durring assembly? */
+	  o->mask = id++;	/* FIXME how to catch during assembly? */
 	  o->match = 0;		/* for macros, the insn_isa number */
 	  o->pinfo = INSN_MACRO;
 #endif
@@ -616,7 +616,7 @@
       struct itbl_entry *r;
       unsigned long value;
 
-      if (f == e->fields)	/* First operand is preceeded by tab.  */
+      if (f == e->fields)	/* First operand is preceded by tab.  */
 	strcat (s, "\t");
       else			/* ','s separate following operands.  */
 	strcat (s, ",");
Index: itbl-parse.y
===================================================================
RCS file: /cvs/src/src/gas/itbl-parse.y,v
retrieving revision 1.3
diff -u -r1.3 itbl-parse.y
--- itbl-parse.y	17 Oct 2002 01:29:36 -0000	1.3
+++ itbl-parse.y	27 Oct 2003 12:40:45 -0000
@@ -152,7 +152,7 @@
 	    char -> any printable character
 	    ltr -> ['a'..'z'|'A'..'Z'] 
 	    dec -> ['0'..'9']*	    	    	    	    	     ; value in decimal
-	    hex -> '0x'['0'..'9' | 'a'..'f' | 'A'..'F']*	; value in hexidecimal 
+	    hex -> '0x'['0'..'9' | 'a'..'f' | 'A'..'F']*	; value in hexadecimal 
 
 
 Examples
@@ -239,7 +239,7 @@
 
 ----
 FIXME! should really change lexical analyzer 
-to recognize 'dreg' etc. in context sensative way.
+to recognize 'dreg' etc. in context sensitive way.
 Currently function names or mnemonics may be incorrectly parsed as keywords
 
 FIXME! hex is ambiguous with any digit
Index: macro.h
===================================================================
RCS file: /cvs/src/src/gas/macro.h,v
retrieving revision 1.7
diff -u -r1.7 macro.h
--- macro.h	2 Dec 2002 15:42:08 -0000	1.7
+++ macro.h	27 Oct 2003 12:40:45 -0000
@@ -35,7 +35,7 @@
    list of formal arguments, and also keeps a hash table which points
    into the list to speed up formal search.  Each formal knows its
    name and its default value.  Each time the macro is expanded, the
-   formals get the actual values attatched to them.  */
+   formals get the actual values attached to them.  */
 
 /* Describe the formal arguments to a macro.  */
 
Index: read.c
===================================================================
RCS file: /cvs/src/src/gas/read.c,v
retrieving revision 1.69
diff -u -r1.69 read.c
--- read.c	16 Aug 2003 14:04:48 -0000	1.69
+++ read.c	27 Oct 2003 12:40:47 -0000
@@ -32,7 +32,7 @@
    grow when we do 4361 style flonums.  */
 #define MAXIMUM_NUMBER_OF_CHARS_FOR_FLOAT (16)
 
-/* Routines that read assembler source text to build spagetti in memory.
+/* Routines that read assembler source text to build spaghetti in memory.
    Another group of these functions is in the expr.c module.  */
 
 #include "as.h"
@@ -623,7 +623,7 @@
 		}
 	    }
 
-	  /* We are at the begining of a line, or similar place.
+	  /* We are at the beginning of a line, or similar place.
 	     We expect a well-formed assembler statement.
 	     A "symbol-name:" is a statement.
 
@@ -982,7 +982,7 @@
 		  /* The end of the #APP wasn't in this buffer.  We
 		     keep reading in buffers until we find the #NO_APP
 		     that goes with this #APP  There is one.  The specs
-		     guarentee it...  */
+		     guarantee it...  */
 		  tmp_len = buffer_limit - s;
 		  tmp_buf = xmalloc (tmp_len + 1);
 		  memcpy (tmp_buf, s, tmp_len);
@@ -3800,7 +3800,7 @@
    them in words, longs, etc. and we'll pack them in target byte order
    for you.
 
-   The rules are: pack least significat bit first, if a field doesn't
+   The rules are: pack least significant bit first, if a field doesn't
    entirely fit, put it in the next unit.  Overflowing the bitfield is
    explicitly *not* even a warning.  The bitwidth should be considered
    a "mask".
@@ -4131,7 +4131,7 @@
    by 0d 0f 0g or 0h. After observing the STRANGE way my BSD AS does its
    reading, I decided to be incompatible. This always tries to give you
    rounded bits to the precision of the pseudo-op. Former AS did premature
-   truncatation, restored noisy bits instead of trailing 0s AND gave you
+   truncation, restored noisy bits instead of trailing 0s AND gave you
    a choice of 2 flavours of noise according to which of 2 floating-point
    scanners you directed AS to use.
 
@@ -5344,7 +5344,7 @@
    This call avoids macro/conditionals nesting checking, since the contents of
    the line are assumed to replace the contents of a line already scanned.
 
-   An appropriate use of this function would be substition of input lines when
+   An appropriate use of this function would be substitution of input lines when
    called by md_start_line_hook().  The given line is assumed to already be
    properly scrubbed.  */
 
Index: sb.c
===================================================================
RCS file: /cvs/src/src/gas/sb.c,v
retrieving revision 1.4
diff -u -r1.4 sb.c
--- sb.c	8 Mar 2001 23:24:22 -0000	1.4
+++ sb.c	27 Oct 2003 12:40:48 -0000
@@ -265,7 +265,7 @@
 }
 
 /* start at the index idx into the sb at ptr. skips whitespace,
-   a comma and any following whitespace. returnes the index of the
+   a comma and any following whitespace. returns the index of the
    next character.  */
 
 int
Index: sb.h
===================================================================
RCS file: /cvs/src/src/gas/sb.h,v
retrieving revision 1.4
diff -u -r1.4 sb.h
--- sb.h	8 Mar 2001 23:24:22 -0000	1.4
+++ sb.h	27 Oct 2003 12:40:48 -0000
@@ -44,7 +44,7 @@
    Obstacks provide all the functionality needed, but are too
    complicated, hence the sb.
 
-   An sb is allocated by the caller, and is initialzed to point to an
+   An sb is allocated by the caller, and is initialized to point to an
    sb_element.  sb_elements are kept on a free lists, and used when
    needed, replaced onto the free list when unused.
  */
Index: symbols.c
===================================================================
RCS file: /cvs/src/src/gas/symbols.c,v
retrieving revision 1.46
diff -u -r1.46 symbols.c
--- symbols.c	27 May 2003 19:19:29 -0000	1.46
+++ symbols.c	27 Oct 2003 12:40:48 -0000
@@ -1464,7 +1464,7 @@
   return symbol_name_build;
 }
 
-/* Sombody else's idea of local labels. They are made by "n:" where n
+/* Somebody else's idea of local labels. They are made by "n:" where n
    is any decimal digit. Refer to them with
     "nb" for previous (backward) n:
    or "nf" for next (forward) n:.
Index: symbols.h
===================================================================
RCS file: /cvs/src/src/gas/symbols.h,v
retrieving revision 1.13
diff -u -r1.13 symbols.h
--- symbols.h	27 May 2003 16:00:04 -0000	1.13
+++ symbols.h	27 Oct 2003 12:40:49 -0000
@@ -131,7 +131,7 @@
     symbolS *sub;
     offsetT addnum;
 
-    int added;			/* nasty thing happend yet? */
+    int added;			/* nasty thing happened yet? */
     /* 1: added and has a long-jump */
     /* 2: added but uses someone elses long-jump */
 


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: listing.c
===================================================================
RCS file: /cvs/src/src/gas/listing.c,v
retrieving revision 1.21
diff -u -r1.21 listing.c
--- listing.c	26 Jun 2002 01:18:42 -0000	1.21
+++ listing.c	27 Oct 2003 12:40:45 -0000
@@ -65,7 +65,7 @@
  The function listing_newline remembers the frag associated with the
  newline, and creates a new frag - note that this is wasteful, but not
  a big deal, since listing slows things down a lot anyway.  The
- function also rememebers when the filename changes.
+ function also remembers when the filename changes.
 
  When all the input has finished, and gas has had a chance to settle
  down, the listing is output. This is done by running down the list of
@@ -86,7 +86,7 @@
  LISTING_LHS_WIDTH_SECOND   Number of words for the data on the lhs
  			for the second line
 
- LISTING_LHS_CONT_LINES	Max number of lines to use up for a continutation
+ LISTING_LHS_CONT_LINES	Max number of lines to use up for a continuation
  LISTING_RHS_WIDTH      Number of chars from the input file to print
                         on a line
 */
@@ -127,7 +127,7 @@
   int                       at_end;
 } file_info_type;
 
 /* This structure rememebrs which line from which file goes into which
    frag.  */
 struct list_info_struct {
   /* Frag which this line of source is nearest to.  */
@@ -127,7 +127,7 @@
 } file_info_type;
 
-/* This structure rememebrs which line from which file goes into which
+/* This structure remembers which line from which file goes into which
    frag.  */
 struct list_info_struct {